# MIT License
# 
# Copyright (c) 2020 MiscellaneousStuff
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Print the valid actions."""

from absl import app
from absl import flags

from pylol.lib import actions
from pylol.lib import features
from pylol.lib import point_flag

FLAGS = flags.FLAGS
point_flag.DEFINE_point("feature_map_size", "16000",
                        "Resolution for screen feature layers.")
point_flag.DEFINE_point("feature_move_range", "8",
                        "Resolution for screen feature layers.")

def main(unused_argv):
    """Print the valid actions."""
    feats = features.Features(
        features.AgentInterfaceFormat(
            feature_dimensions=features.Dimensions(
                map=FLAGS.feature_map_size,
                move_range=FLAGS.feature_move_range
            )
        )
    )
    action_spec = feats.action_spec()
    flattened = 0
    count = 0
    for func in action_spec.functions:
        count += 1
        act_flat = 1
        for arg in func.args:
            for size in arg.sizes:
                act_flat *= size
        flattened += act_flat
        print(func.str(True))
    print("Total base actions:", count)
    print("Total possible actions (flattened):", flattened)

if __name__ == "__main__":
    app.run(main)